@@ -16,6 +16,10 @@ use crate::location::Location;
 use crate::output::Output;
 use crate::v0;
 
+pub(crate) use gitlab::GitlabGenericPackage;
+
+mod gitlab;
+
 pub(crate) type ApiResult<T> = Result<Output<T>, anyhow::Error>;
 #[derive(Debug)]
 pub(crate) struct Api {
@@ -25,16 +29,16 @@ pub(crate) struct Api {
 }
 
 impl Api {
-    pub(crate) fn new(management: &str, token: Option<&str>) -> Self {
+    pub(crate) fn new(management: &str, prefix: &str, token: Option<&str>) -> Self {
         let user_agent = format!("{}/{}", env!("CARGO_PKG_NAME"), env!("CARGO_PKG_VERSION"));
         let token = token.map(String::from).map(SecretString::new);
 
         let base = if management.starts_with("http") {
-            format!("{}{}", management, v0::VERSION)
+            format!("{}{}", management, prefix)
         } else if management.starts_with("api.") && management.ends_with(".statehub.io") {
-            format!("https://{}{}", management, v0::VERSION)
+            format!("https://{}{}", management, prefix)
         } else {
-            format!("http://{}:3000{}", management, v0::VERSION)
+            format!("http://{}:3000{}", management, prefix)
         };
 
         log::debug!("Using API at {} with token {:?}", base, token);
