@@ -5,12 +5,15 @@
 
 use std::time::Duration;
 
+use anyhow::Context;
 use indexmap::IndexMap;
 use serde_json as json;
 use tokio::time;
 
 use super::*;
 
+mod gitlab;
+
 impl StateHub {
     pub(super) async fn add_location_helper(
         &self,
@@ -315,6 +318,36 @@ or run following commands before running 'statehub register-cluster`
         self.error(stderr)?;
         Ok(())
     }
+
+    pub(super) async fn check_for_update_helper(
+        &self,
+    ) -> Option<(semver::Version, semver::Version)> {
+        let current = Self::VERSION.parse::<semver::Version>().ok()?;
+        let latest = self.latest_version().await.ok()?;
+
+        log::debug!(
+            "Check for update - current: {}, latest: {}",
+            current,
+            latest
+        );
+
+        if latest > current {
+            Some((current, latest))
+        } else {
+            None
+        }
+    }
+
+    pub(super) async fn update_helper(&self, version: semver::Version) -> anyhow::Result<()> {
+        let version = version.to_string();
+        self.inform(format_args!("Downloading version {}", version))?;
+        let file = self
+            .get_package("statehub", &version)
+            .await
+            .context(format!("Downloading version {}", version))?;
+        log::debug!("Downloaded {} bytes", file.len());
+        Ok(())
+    }
 }
 
 fn is_volume_not_found(err: &anyhow::Error) -> bool {
